@@ -14,6 +14,7 @@ from .database import Connection
 from .database import keys_submissions
 from .database import select_all
 from .download import submission_download
+from .download import user_clean_name
 from .download import user_download
 from .settings import setting_write
 
@@ -43,11 +44,13 @@ def submissions_download(api: FAAPI, db: Connection, sub_ids: List[str]):
 
 
 def users_update(api: FAAPI, db: Connection):
-    users_folders: List[Tuple[str, str]] = select_all(db, "USERS", ["USERNAME", "FOLDERS"])
     tot: int = 0
     fail: int = 0
-    for user, user_folders in users_folders:
+    for user, user_folders in select_all(db, "USERS", ["USERNAME", "FOLDERS"]):
         for folder in user_folders.split(","):
+            if folder.lower() == "extras":
+                print(f"Unsupported: {user}/{folder}")
+                continue
             print(f"Downloading: {user}/{folder}")
             tot_tmp, fail_tmp = user_download(api, db, user, folder, 1)
             tot += tot_tmp
@@ -104,7 +107,7 @@ def submissions_search(db: Connection,
                        description: List[str] = None, tags: List[str] = None, category: List[str] = None,
                        species: List[str] = None, gender: List[str] = None, rating: List[str] = None
                        ) -> List[tuple]:
-    author = [] if author is None else author
+    author = [] if author is None else list(map(user_clean_name, author))
     title = [] if title is None else title
     date = [] if date is None else date
     description = [] if description is None else description
@@ -122,7 +125,7 @@ def submissions_search(db: Connection,
         " OR ".join(["lower(GENDER) like ?"] * len(gender)),
         " OR ".join(["lower(SPECIES) like ?"] * len(species)),
         " OR ".join(["lower(CATEGORY) like ?"] * len(category)),
-        " OR ".join(["lower(AUTHOR) like ?"] * len(author)),
+        " OR ".join(['replace(lower(AUTHOR), "_", "") like ?'] * len(author)),
         " OR ".join(["lower(TITLE) like ?"] * len(title)),
         " OR ".join(["lower(TAGS) like ?"] * len(tags)),
         " OR ".join(["lower(DESCRIPTION) like ?"] * len(description))
@@ -140,7 +143,11 @@ def submissions_print(subs: List[tuple], sort: bool = True):
     space_id: int = 10
     space_user: int = 10
     space_date: int = 10
-    space_term: int = get_terminal_size()[0]
+    space_term: int = 10000
+    try:
+        space_term = get_terminal_size()[0]
+    except IOError:
+        pass
 
     index_id: int = keys_submissions.index("ID")
     index_user: int = keys_submissions.index("AUTHOR")
